@@ -73,6 +73,8 @@
 #' * `has_keyword("x")` to select all topics with keyword "x";
 #'   `has_keyword("datasets")` selects all data documentation.
 #' * `has_concept("blah")` to select all topics with concept "blah".
+#'   If you are using roxygen2, `has_concept()` also matches family tags, because
+#'   roxygen2 converts them to concept tags.
 #' * `lacks_concepts(c("concept1", "concept2"))` to select all topics
 #'    without those concepts. This is useful to capture topics not otherwise
 #'    captured by `has_concepts()`.
@@ -100,7 +102,7 @@
 #'
 #' ```
 #' figures:
-#'   dev: grDevices::png
+#'   dev: ragg::agg_png
 #'   dpi: 96
 #'   dev.args: []
 #'   fig.ext: png
@@ -108,6 +110,7 @@
 #'   fig.height: ~
 #'   fig.retina: 2
 #'   fig.asp: 1.618
+#'   bg: NA
 #' ```
 #'
 #' @inheritParams build_articles
@@ -228,14 +231,23 @@ build_reference_topic <- function(topic,
     return(invisible())
 
   cat_line("Reading ", src_path("man", topic$file_in))
-  scoped_file_context(rdname = path_ext_remove(topic$file_in), depth = 1L)
 
-  data <- data_reference_topic(
-    topic,
-    pkg,
-    examples = examples,
-    run_dont_run = run_dont_run
+  data <- withCallingHandlers(
+    data_reference_topic(
+      topic,
+      pkg,
+      examples = examples,
+      run_dont_run = run_dont_run
+    ),
+    error = function(err) {
+      msg <- c(
+        paste0("Failed to parse Rd in ", topic$file_in),
+        i = err$message
+      )
+      abort(msg, parent = err)
+    }
   )
+
   render_page(
     pkg, "reference-topic",
     data = data,
@@ -252,6 +264,9 @@ data_reference_topic <- function(topic,
                                  examples = TRUE,
                                  run_dont_run = FALSE
                                  ) {
+  local_context_eval(pkg$figures, pkg$src_path)
+  withr::local_options(list(downlit.rdname = topic$name))
+
   tag_names <- purrr::map_chr(topic$rd, ~ class(.)[[1]])
   tags <- split(topic$rd, tag_names)
 
@@ -260,8 +275,7 @@ data_reference_topic <- function(topic,
   # Single top-level converted to string
   out$name <- flatten_text(tags$tag_name[[1]][[1]])
   out$title <- extract_title(tags$tag_title)
-
-  out$pagetitle <- paste0(out$title, " \u2014 ", out$name)
+  out$pagetitle <- paste0(strip_html_tags(out$title), " \u2014 ", out$name)
 
   # File source
   out$source <- repo_source(pkg, topic$source)
@@ -294,7 +308,7 @@ data_reference_topic <- function(topic,
   # Everything else stays in original order, and becomes a list of sections.
   section_tags <- c(
     "tag_details", "tag_references", "tag_source", "tag_format",
-    "tag_note", "tag_seealso", "tag_section", "tag_value"
+    "tag_note", "tag_seealso", "tag_section", "tag_value", "tag_author"
   )
   sections <- topic$rd[tag_names %in% section_tags]
   out$sections <- sections %>%
