@@ -94,28 +94,14 @@ copy_asset_dir <- function(pkg, from_dir, file_regexp = NULL) {
   file_copy_to(pkg, files, pkg$dst_path, from_dir = from_path)
 }
 
-timestamp <- function() {
-  x <- Sys.time()
-  attr(x, "tzone") <- "UTC"
-  strftime(x, "%Y-%m-%dT%H:%MZ", tz = "UTC")
+timestamp <- function(time = Sys.time()) {
+  attr(time, "tzone") <- "UTC"
+  strftime(time, "%Y-%m-%dT%H:%MZ", tz = "UTC")
 }
 
 # Generate site meta data file (available to website viewers)
 build_site_meta <- function(pkg = ".") {
-  meta <- list(
-    pandoc = as.character(rmarkdown::pandoc_version()),
-    pkgdown = as.character(utils::packageDescription("pkgdown", fields = "Version")),
-    pkgdown_sha = utils::packageDescription("pkgdown")$GithubSHA1,
-    articles = as.list(pkg$article_index),
-    last_built = timestamp()
-  )
-
-  if (!is.null(pkg$meta$url)) {
-    meta$urls <- list(
-      reference = paste0(pkg$meta$url, "/reference"),
-      article = paste0(pkg$meta$url, "/articles")
-    )
-  }
+  meta <- site_meta(pkg)
 
   # Install pkgdown.yml to ./inst if requested,
   install_metadata <- pkg$install_metadata %||% FALSE
@@ -131,6 +117,27 @@ build_site_meta <- function(pkg = ".") {
   invisible()
 }
 
+site_meta <- function(pkg) {
+  article_index <- set_names(path_file(pkg$vignettes$file_out), pkg$vignettes$name)
+
+  meta <- list(
+    pandoc = as.character(rmarkdown::pandoc_version()),
+    pkgdown = as.character(utils::packageDescription("pkgdown", fields = "Version")),
+    pkgdown_sha = utils::packageDescription("pkgdown")$GithubSHA1,
+    articles = as.list(article_index),
+    last_built = timestamp()
+  )
+
+  if (!is.null(pkg$meta$url)) {
+    meta$urls <- list(
+      reference = paste0(pkg$meta$url, "/reference"),
+      article = paste0(pkg$meta$url, "/articles")
+    )
+  }
+
+  print_yaml(meta)
+}
+
 is_non_pkgdown_site <- function(dst_path) {
   if (!dir_exists(dst_path)) {
     return(FALSE)
