@@ -1,11 +1,11 @@
 markdown <- function(path = NULL, ..., strip_header = FALSE) {
   tmp <- tempfile(fileext = ".html")
-  on.exit(file_delete(tmp), add = TRUE)
+  on.exit(unlink(tmp), add = TRUE)
 
   if (rmarkdown::pandoc_available("2.0")) {
-    from <- "markdown_github-hard_line_breaks+smart+auto_identifiers+tex_math_dollars+tex_math_single_backslash+markdown_in_html_blocks"
+    from <- "markdown_github-hard_line_breaks+smart+auto_identifiers+tex_math_dollars+tex_math_single_backslash+markdown_in_html_blocks+header_attributes"
   } else if (rmarkdown::pandoc_available("1.12.3")) {
-    from <- "markdown_github-hard_line_breaks+tex_math_dollars+tex_math_single_backslash"
+    from <- "markdown_github-hard_line_breaks+tex_math_dollars+tex_math_single_backslash+header_attributes"
   } else {
     stop("Pandoc not available", call. = FALSE)
   }
@@ -37,7 +37,7 @@ markdown <- function(path = NULL, ..., strip_header = FALSE) {
     xml2::xml_remove(h1)
   }
 
-  tweak_code(xml)
+  downlit::downlit_html_node(xml)
   tweak_md_links(xml)
   tweak_anchors(xml, only_contents = FALSE)
 
@@ -62,7 +62,6 @@ markdown_text <- function(text, ...) {
     return(NULL)
   }
 
-
   tmp <- tempfile()
   on.exit(unlink(tmp), add = TRUE)
 
